Re-exports
pub use crate::Request;
Structs
- DynLazy
Response - Lazy
Response - A lazy api response which you can trigger through the
runcallback - Options
- Use API Options
Functions
- use_api
- The basic api hook which requests data on mount and preserves its data through out the component lifetime
- use_
api_ dynamic - Useful when not wanting to run a request on mount, e.g. for a logout button You may run the request multiple times through multiple emits of the callback
- use_
api_ dynamic_ with_ options - Useful when not wanting to run a request on mount, e.g. for a logout button You may run the request multiple times through multiple emits of the callback
- use_
api_ lazy - Useful when not wanting to run a request on mount, e.g. for a logout button You may run the request multiple times through multiple emits of the callback
- use_
api_ lazy_ with_ options - Useful when not wanting to run a request on mount, e.g. for a logout button You may run the request multiple times through multiple emits of the callback
- use_
api_ with_ options - The basic api hook which requests data on mount and preserves its data through out the component lifetime.