Trait yew_api_hook::Request
source · pub trait Request: Debug + PartialEq + Clone {
type Error: Clone + Debug + PartialEq + 'static;
type Output: Clone + Debug + PartialEq + 'static;
fn run<'life0, 'async_trait>(
&'life0 self
) -> Pin<Box<dyn Future<Output = Result<Self::Output, Self::Error>> + 'async_trait>>
where
Self: 'async_trait,
'life0: 'async_trait;
fn store(_: Self::Output) { ... }
}Expand description
The core request trait which has to be implemented for all handler which can be executed through the use api hook.